summaryrefslogtreecommitdiff
path: root/libxklavier/xklavier.h
diff options
context:
space:
mode:
Diffstat (limited to 'libxklavier/xklavier.h')
-rw-r--r--libxklavier/xklavier.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/libxklavier/xklavier.h b/libxklavier/xklavier.h
index 83c1737..72ac5e7 100644
--- a/libxklavier/xklavier.h
+++ b/libxklavier/xklavier.h
@@ -221,11 +221,11 @@ extern "C"
/**
* Finds the state for a given window (for its "App window").
* @param win is a target window
* @param state_return is a structure to store the state
* @return True on success, otherwise False
* (the error message can be obtained using xkl_GetLastError).
*/
- extern gboolean xkl_state_get( Window win, XklState * state_return );
+ extern gboolean xkl_state_get( Window win, XklState * state_out );
/**
* Drops the state of a given window (of its "App window").
@@ -221,11 +221,11 @@ extern "C"
* Finds the state for a given window (for its "App window").
* @param win is a target window
- * @param state_return is a structure to store the state
+ * @param state_out is a structure to store the state
* @return True on success, otherwise False
* (the error message can be obtained using xkl_GetLastError).